<?php

namespace Drupal\uw_cfg_common\Routing;

use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\RouteCollection;

/**
 * Listens to the dynamic route events.
 */
class UwNodeAccessRouteSubscriber extends RouteSubscriberBase {

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    $access_route_names = [
      // Dashboard config: admin/config/dashboards/dashboardssettings.
      'dashboards.dashboards_settings_form',
      // Node pages (/node/{nid}).
      'entity.node.canonical',
      // Node delete pages.
      'entity.node.delete_form',
      // Menu link edit pages.
      'menu_ui.link_edit',
      // Role Expire config: admin/config/system/role-expire.
      'role_expire.config',
    ];
    foreach ($access_route_names as $route_name) {
      if ($route = $collection->get($route_name)) {
        $route->setRequirement('_custom_access', 'Drupal\uw_cfg_common\Access\UwNodeAccessCheck::access');
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    // Run this implementation of alterRoutes() after menu_admin_per_menu, which
    // has priority -220.
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', -300];
    return $events;
  }

}
